@@ -320,7 +320,7 @@ class Arbiter(object):
         sig = signal.SIGQUIT
         if not graceful:
             sig = signal.SIGTERM
-        limit = time.time() + self.timeout
+        limit = time.time() + self.cfg.graceful_timeout
         while self.WORKERS and time.time() < limit:
             self.kill_workers(sig)
             time.sleep(0.1)
@@ -359,7 +359,7 @@ class Arbiter(object):
             self.LISTENER = create_socket(self.cfg, self.log)
             self.log.info("Listening at: %s", self.LISTENER)
 
-        # spawn new workers with new app & conf
+        # do some actions on reload
         self.cfg.on_reload(self)
 
         # unlink pidfile
@@ -374,9 +374,11 @@ class Arbiter(object):
         # set new proc_name
         util._setproctitle("master [%s]" % self.proc_name)
 
-        # manage workers
-        self.log.reopen_files()
+        # spawn new workers
+        for i in range(self.cfg.workers):
+            self.spawn_worker()
 
+        # manage workers
         self.manage_workers()
 
     def murder_workers(self):
